==> django_microsoft_sso-2.0.1.tar.gz: django_microsoft_sso-2.0.1/django_microsoft_sso/conf.py <==
from django.conf import settings

MICROSOFT_SSO_APPLICATION_ID = getattr(settings, "MICROSOFT_SSO_APPLICATION_ID", None)
MICROSOFT_SSO_CLIENT_SECRET = getattr(settings, "MICROSOFT_SSO_CLIENT_SECRET", None)
MICROSOFT_SSO_SCOPES = getattr(
    settings,
    "MICROSOFT_SSO_SCOPES",
    ["User.ReadBasic.All"],
)
MICROSOFT_SSO_TIMEOUT = getattr(settings, "MICROSOFT_SSO_TIMEOUT", 10)

MICROSOFT_SSO_ALLOWABLE_DOMAINS = getattr(
    settings, "MICROSOFT_SSO_ALLOWABLE_DOMAINS", []
)
MICROSOFT_SSO_AUTO_CREATE_FIRST_SUPERUSER = getattr(
    settings, "MICROSOFT_SSO_AUTO_CREATE_FIRST_SUPERUSER", False
)
MICROSOFT_SSO_SESSION_COOKIE_AGE = getattr(
    settings, "MICROSOFT_SSO_SESSION_COOKIE_AGE", 3600
)
MICROSOFT_SSO_ENABLED = getattr(settings, "MICROSOFT_SSO_ENABLED", True)
MICROSOFT_SSO_SUPERUSER_LIST = getattr(settings, "MICROSOFT_SSO_SUPERUSER_LIST", [])
MICROSOFT_SSO_STAFF_LIST = getattr(settings, "MICROSOFT_SSO_STAFF_LIST", [])
MICROSOFT_SSO_CALLBACK_DOMAIN = getattr(settings, "MICROSOFT_SSO_CALLBACK_DOMAIN", None)
MICROSOFT_SSO_AUTO_CREATE_USERS = getattr(
    settings, "MICROSOFT_SSO_AUTO_CREATE_USERS", True
)

MICROSOFT_SSO_AUTHENTICATION_BACKEND = getattr(
    settings, "MICROSOFT_SSO_AUTHENTICATION_BACKEND", None
)

MICROSOFT_SSO_PRE_LOGIN_CALLBACK = getattr(
    settings,
    "MICROSOFT_SSO_PRE_LOGIN_CALLBACK",
    "django_microsoft_sso.hooks.pre_login_user",
)

MICROSOFT_SSO_LOGO_URL = getattr(
    settings,
    "MICROSOFT_SSO_LOGO_URL",
    "https://purepng.com/public/uploads/large/purepng.com-"
    "microsoft-logo-iconlogobrand-logoiconslogos-251519939091wmudn.png",
)

MICROSOFT_SSO_TEXT = getattr(settings, "MICROSOFT_SSO_TEXT", "Sign in with Microsoft")
MICROSOFT_SSO_NEXT_URL = getattr(settings, "MICROSOFT_SSO_NEXT_URL", "admin:index")
MICROSOFT_SSO_LOGIN_FAILED_URL = getattr(
    settings, "MICROSOFT_SSO_LOGIN_FAILED_URL", "admin:index"
)
MICROSOFT_SSO_SAVE_ACCESS_TOKEN = getattr(
    settings, "MICROSOFT_SSO_SAVE_ACCESS_TOKEN", False
)
MICROSOFT_SSO_ALWAYS_UPDATE_USER_DATA = getattr(
    settings, "MICROSOFT_SSO_ALWAYS_UPDATE_USER_DATA", False
)
MICROSOFT_SSO_LOGOUT_REDIRECT_PATH = getattr(
    settings, "MICROSOFT_SSO_LOGOUT_REDIRECT_PATH", "admin:index"
)
MICROSOFT_SLO_ENABLED = getattr(settings, "MICROSOFT_SLO_ENABLED", False)
SSO_USE_ALTERNATE_W003 = getattr(settings, "SSO_USE_ALTERNATE_W003", False)

if SSO_USE_ALTERNATE_W003:
    from django_microsoft_sso.checks.warnings import register_sso_check  # noqa

==> django_microsoft_sso-2.1.0.tar.gz: django_microsoft_sso-2.1.0/django_microsoft_sso/conf.py <==
from django.conf import settings

MICROSOFT_SSO_APPLICATION_ID = getattr(settings, "MICROSOFT_SSO_APPLICATION_ID", None)
MICROSOFT_SSO_CLIENT_SECRET = getattr(settings, "MICROSOFT_SSO_CLIENT_SECRET", None)
MICROSOFT_SSO_SCOPES = getattr(
    settings,
    "MICROSOFT_SSO_SCOPES",
    ["User.ReadBasic.All"],
)
MICROSOFT_SSO_TIMEOUT = getattr(settings, "MICROSOFT_SSO_TIMEOUT", 10)

MICROSOFT_SSO_ALLOWABLE_DOMAINS = getattr(settings, "MICROSOFT_SSO_ALLOWABLE_DOMAINS", [])
MICROSOFT_SSO_AUTO_CREATE_FIRST_SUPERUSER = getattr(
    settings, "MICROSOFT_SSO_AUTO_CREATE_FIRST_SUPERUSER", False
)
MICROSOFT_SSO_SESSION_COOKIE_AGE = getattr(
    settings, "MICROSOFT_SSO_SESSION_COOKIE_AGE", 3600
)
MICROSOFT_SSO_ENABLED = getattr(settings, "MICROSOFT_SSO_ENABLED", True)
MICROSOFT_SSO_SUPERUSER_LIST = getattr(settings, "MICROSOFT_SSO_SUPERUSER_LIST", [])
MICROSOFT_SSO_STAFF_LIST = getattr(settings, "MICROSOFT_SSO_STAFF_LIST", [])
MICROSOFT_SSO_CALLBACK_DOMAIN = getattr(settings, "MICROSOFT_SSO_CALLBACK_DOMAIN", None)
MICROSOFT_SSO_AUTO_CREATE_USERS = getattr(settings, "MICROSOFT_SSO_AUTO_CREATE_USERS", True)

MICROSOFT_SSO_AUTHENTICATION_BACKEND = getattr(
    settings, "MICROSOFT_SSO_AUTHENTICATION_BACKEND", None
)

MICROSOFT_SSO_PRE_LOGIN_CALLBACK = getattr(
    settings,
    "MICROSOFT_SSO_PRE_LOGIN_CALLBACK",
    "django_microsoft_sso.hooks.pre_login_user",
)

MICROSOFT_SSO_LOGO_URL = getattr(
    settings,
    "MICROSOFT_SSO_LOGO_URL",
    "https://purepng.com/public/uploads/large/purepng.com-"
    "microsoft-logo-iconlogobrand-logoiconslogos-251519939091wmudn.png",
)

MICROSOFT_SSO_TEXT = getattr(settings, "MICROSOFT_SSO_TEXT", "Sign in with Microsoft")
MICROSOFT_SSO_NEXT_URL = getattr(settings, "MICROSOFT_SSO_NEXT_URL", "admin:index")
MICROSOFT_SSO_LOGIN_FAILED_URL = getattr(
    settings, "MICROSOFT_SSO_LOGIN_FAILED_URL", "admin:index"
)
MICROSOFT_SSO_SAVE_ACCESS_TOKEN = getattr(
    settings, "MICROSOFT_SSO_SAVE_ACCESS_TOKEN", False
)
MICROSOFT_SSO_ALWAYS_UPDATE_USER_DATA = getattr(
    settings, "MICROSOFT_SSO_ALWAYS_UPDATE_USER_DATA", False
)
MICROSOFT_SSO_LOGOUT_REDIRECT_PATH = getattr(
    settings, "MICROSOFT_SSO_LOGOUT_REDIRECT_PATH", "admin:index"
)
MICROSOFT_SLO_ENABLED = getattr(settings, "MICROSOFT_SLO_ENABLED", False)
SSO_USE_ALTERNATE_W003 = getattr(settings, "SSO_USE_ALTERNATE_W003", False)

if SSO_USE_ALTERNATE_W003:
    from django_microsoft_sso.checks.warnings import register_sso_check  # noqa
